EXPORTS
	??0TXmlEngParsingOptions@@QAE@I@Z @ 1 NONAME ; TXmlEngParsingOptions::TXmlEngParsingOptions(unsigned int)
	?DeserializeL@CXmlEngDeserializer@@UAEXAAVRFs@@ABVTDesC16@@ABVTXmlEngParsingOptions@@@Z @ 2 NONAME ; void CXmlEngDeserializer::DeserializeL(class RFs &, class TDesC16 const &, class TXmlEngParsingOptions const &)
	?DeserializeL@CXmlEngDeserializer@@UAEXABVTDesC16@@ABVTXmlEngParsingOptions@@@Z @ 3 NONAME ; void CXmlEngDeserializer::DeserializeL(class TDesC16 const &, class TXmlEngParsingOptions const &)
	?DeserializeL@CXmlEngDeserializer@@UAEXABVTDesC8@@ABVTXmlEngParsingOptions@@@Z @ 4 NONAME ; void CXmlEngDeserializer::DeserializeL(class TDesC8 const &, class TXmlEngParsingOptions const &)
	?DeserializeL@CXmlEngDeserializer@@UAEXXZ @ 5 NONAME ; void CXmlEngDeserializer::DeserializeL(void)
	?DeserializeL@CXmlEngDeserializerDOM@@QAE?AVRXmlEngDocument@@AAVRFs@@ABVTDesC16@@W4TXmlEngDeserializerType@@@Z @ 6 NONAME ; class RXmlEngDocument CXmlEngDeserializerDOM::DeserializeL(class RFs &, class TDesC16 const &, enum TXmlEngDeserializerType)
	?DeserializeL@CXmlEngDeserializerDOM@@QAE?AVRXmlEngDocument@@ABVTDesC16@@W4TXmlEngDeserializerType@@@Z @ 7 NONAME ; class RXmlEngDocument CXmlEngDeserializerDOM::DeserializeL(class TDesC16 const &, enum TXmlEngDeserializerType)
	?DeserializeL@CXmlEngDeserializerDOM@@QAE?AVRXmlEngDocument@@ABVTDesC8@@W4TXmlEngDeserializerType@@@Z @ 8 NONAME ; class RXmlEngDocument CXmlEngDeserializerDOM::DeserializeL(class TDesC8 const &, enum TXmlEngDeserializerType)
	?DeserializeL@CXmlEngDeserializerDOM@@QAE?AVRXmlEngDocument@@XZ @ 9 NONAME ; class RXmlEngDocument CXmlEngDeserializerDOM::DeserializeL(void)
	?NewL@CXmlEngDeserializer@@SAPAV1@AAVMContentHandler@Xml@@W4TXmlEngDeserializerType@@@Z @ 10 NONAME ; class CXmlEngDeserializer * CXmlEngDeserializer::NewL(class Xml::MContentHandler &, enum TXmlEngDeserializerType)
	?DisableFeature@CXmlEngDeserializer@@UAEHH@Z @ 11 NONAME ; int CXmlEngDeserializer::DisableFeature(int)
	?DisableFeature@CXmlEngDeserializerXOP@@UAEHH@Z @ 12 NONAME ; int CXmlEngDeserializerXOP::DisableFeature(int)
	?EnableFeature@CXmlEngDeserializer@@UAEHH@Z @ 13 NONAME ; int CXmlEngDeserializer::EnableFeature(int)
	?EnableFeature@CXmlEngDeserializerXOP@@UAEHH@Z @ 14 NONAME ; int CXmlEngDeserializerXOP::EnableFeature(int)
	?ExternalData@CXmlEngDeserializer@@QAEPAV?$RArray@VTXmlEngDataContainer@@@@XZ @ 15 NONAME ; class RArray<class TXmlEngDataContainer> * CXmlEngDeserializer::ExternalData(void)
	?ExternalData@CXmlEngDeserializerDOM@@QAEPAV?$RArray@VTXmlEngDataContainer@@@@XZ @ 16 NONAME ; class RArray<class TXmlEngDataContainer> * CXmlEngDeserializerDOM::ExternalData(void)
	?IsFeatureEnabled@CXmlEngDeserializer@@UBEHH@Z @ 17 NONAME ; int CXmlEngDeserializer::IsFeatureEnabled(int) const
	?IsFeatureEnabled@CXmlEngDeserializerXOP@@UBEHH@Z @ 18 NONAME ; int CXmlEngDeserializerXOP::IsFeatureEnabled(int) const
	?NewL@CXmlEngDeserializerDOM@@SAPAV1@XZ @ 19 NONAME ; class CXmlEngDeserializerDOM * CXmlEngDeserializerDOM::NewL(void)
	?NewL@CXmlEngSerializerXOP@@SAPAV1@H@Z @ 20 NONAME ; class CXmlEngSerializerXOP * CXmlEngSerializerXOP::NewL(int)
	?ParsingOptions@CXmlEngDeserializer@@UAEABVTXmlEngParsingOptions@@XZ @ 21 NONAME ; class TXmlEngParsingOptions const & CXmlEngDeserializer::ParsingOptions(void)
	?SerializeL@CXmlEngSerializer@@UAEHAAVRBuf8@@VTXmlEngNode@@ABVTXmlEngSerializationOptions@@@Z @ 22 NONAME ; int CXmlEngSerializer::SerializeL(class RBuf8 &, class TXmlEngNode, class TXmlEngSerializationOptions const &)
	?SerializeL@CXmlEngSerializer@@UAEHAAVRFs@@ABVTDesC16@@VTXmlEngNode@@ABVTXmlEngSerializationOptions@@@Z @ 23 NONAME ; int CXmlEngSerializer::SerializeL(class RFs &, class TDesC16 const &, class TXmlEngNode, class TXmlEngSerializationOptions const &)
	?SerializeL@CXmlEngSerializer@@UAEHABVTDesC16@@VTXmlEngNode@@ABVTXmlEngSerializationOptions@@@Z @ 24 NONAME ; int CXmlEngSerializer::SerializeL(class TDesC16 const &, class TXmlEngNode, class TXmlEngSerializationOptions const &)
	?SerializeL@CXmlEngSerializer@@UAEHVTXmlEngNode@@@Z @ 25 NONAME ; int CXmlEngSerializer::SerializeL(class TXmlEngNode)
	?NewL@CXmlEngSerializer@@SAPAV1@W4TXmlEngSerializerType@@@Z @ 26 NONAME ; class CXmlEngSerializer * CXmlEngSerializer::NewL(enum TXmlEngSerializerType)
	?SetContentHandlerL@CXmlEngDeserializer@@UAEXAAVMContentHandler@Xml@@@Z @ 27 NONAME ; void CXmlEngDeserializer::SetContentHandlerL(class Xml::MContentHandler &)
	?SetInputBuffer@CXmlEngDeserializer@@QAEXABVTDesC8@@@Z @ 28 NONAME ; void CXmlEngDeserializer::SetInputBuffer(class TDesC8 const &)
	?SetInputBuffer@CXmlEngDeserializerDOM@@QAEXABVTDesC8@@W4TXmlEngDeserializerType@@@Z @ 29 NONAME ; void CXmlEngDeserializerDOM::SetInputBuffer(class TDesC8 const &, enum TXmlEngDeserializerType)
	?SetInputFileL@CXmlEngDeserializer@@QAEXABVTDesC16@@@Z @ 30 NONAME ; void CXmlEngDeserializer::SetInputFileL(class TDesC16 const &)
	?SetInputFileL@CXmlEngDeserializerDOM@@QAEXABVTDesC16@@W4TXmlEngDeserializerType@@@Z @ 31 NONAME ; void CXmlEngDeserializerDOM::SetInputFileL(class TDesC16 const &, enum TXmlEngDeserializerType)
	?SetOutput@CXmlEngSerializer@@QAEXAAVMXmlEngOutputStream@@@Z @ 32 NONAME ; void CXmlEngSerializer::SetOutput(class MXmlEngOutputStream &)
	?SetOutput@CXmlEngSerializer@@QAEXAAVRBuf8@@@Z @ 33 NONAME ; void CXmlEngSerializer::SetOutput(class RBuf8 &)
	?SetOutputL@CXmlEngSerializer@@QAEXABVTDesC16@@@Z @ 34 NONAME ; void CXmlEngSerializer::SetOutputL(class TDesC16 const &)
	?SetParsingOptions@CXmlEngDeserializer@@UAEXAAVTXmlEngParsingOptions@@@Z @ 35 NONAME ; void CXmlEngDeserializer::SetParsingOptions(class TXmlEngParsingOptions &)
	?SetSerializationOptions@CXmlEngSerializer@@QAEXAAVTXmlEngSerializationOptions@@@Z @ 36 NONAME ; void CXmlEngSerializer::SetSerializationOptions(class TXmlEngSerializationOptions &)
	?UseDOMImplementationL@CXmlEngDeserializerDOM@@QAEXAAVRXmlEngDOMImplementation@@@Z @ 37 NONAME ; void CXmlEngDeserializerDOM::UseDOMImplementationL(class RXmlEngDOMImplementation &)
	?UseExternalDataL@CXmlEngDeserializer@@QAEXAAV?$RArray@VTXmlEngDataContainer@@@@@Z @ 38 NONAME ; void CXmlEngDeserializer::UseExternalDataL(class RArray<class TXmlEngDataContainer> &)
	?UseExternalDataL@CXmlEngDeserializerDOM@@QAEXAAV?$RArray@VTXmlEngDataContainer@@@@@Z @ 39 NONAME ; void CXmlEngDeserializerDOM::UseExternalDataL(class RArray<class TXmlEngDataContainer> &)

